@@ -16,6 +16,7 @@ from nordea_analytics.curve_variable_names import (
     SpotForward,
 )
 from nordea_analytics.forecast_names import YieldCountry, YieldHorizon, YieldType
+from nordea_analytics.instrument_variable_names import BenchmarkName, BondIndexName
 from nordea_analytics.key_figure_names import (
     BondKeyFigureName,
     CalculatedBondKeyFigureName,
@@ -37,12 +38,14 @@ from nordea_analytics.nalib.value_retrievers.BondKeyFigures import BondKeyFigure
 from nordea_analytics.nalib.value_retrievers.Curve import Curve
 from nordea_analytics.nalib.value_retrievers.CurveDefinition import CurveDefinition
 from nordea_analytics.nalib.value_retrievers.CurveTimeSeries import CurveTimeSeries
+from nordea_analytics.nalib.value_retrievers.DateSequence import DateSequence
 from nordea_analytics.nalib.value_retrievers.FXForecast import FXForecast
 from nordea_analytics.nalib.value_retrievers.IndexComposition import IndexComposition
 from nordea_analytics.nalib.value_retrievers.LiveBondKeyFigures import (
     LiveBondKeyFigures,
 )
 from nordea_analytics.nalib.value_retrievers.LiveBondUniverse import LiveBondUniverse
+from nordea_analytics.nalib.value_retrievers.Quotes import Quotes
 from nordea_analytics.nalib.value_retrievers.ShiftDate import ShiftDate
 from nordea_analytics.nalib.value_retrievers.ShiftDays import ShiftDays
 from nordea_analytics.nalib.value_retrievers.TimeSeries import TimeSeries
@@ -53,6 +56,7 @@ from nordea_analytics.search_bond_names import (
     AssetType,
     CapitalCentres,
     CapitalCentreTypes,
+    InstrumentGroup,
     Issuers,
 )
 
@@ -125,7 +129,15 @@ class NordeaAnalyticsCoreService:
 
     def get_time_series(
         self,
-        symbols: Union[str, List[str]],
+        symbols: Union[
+            str,
+            BondIndexName,
+            BenchmarkName,
+            List[str],
+            List[BenchmarkName],
+            List[BondIndexName],
+            List[Union[str, BenchmarkName, BondIndexName]],
+        ],
         keyfigures: Union[
             str,
             TimeSeriesKeyFigureName,
@@ -295,6 +307,9 @@ class NordeaAnalyticsCoreService:
         currency: str = None,
         issuers: Union[List[Issuers], List[str], Issuers, str] = None,
         asset_types: Union[List[AssetType], List[str], AssetType, str] = None,
+        instrument_groups: Union[
+            List[InstrumentGroup], List[str], InstrumentGroup, str
+        ] = None,
         lower_issue_date: datetime = None,
         upper_issue_date: datetime = None,
         lower_maturity: datetime = None,
@@ -323,6 +338,7 @@ class NordeaAnalyticsCoreService:
             currency: Optional. Issue currency.
             issuers: Optional. Name of issuers.
             asset_types: Optional. Type of asset.
+            instrument_groups: Optional. Type of instrument.
             lower_issue_date: Optional. Minimum (from) issue date.
             upper_issue_date: Optional. Maximum (to) issue date.
             lower_maturity: Optional. Minimum (from) maturity.
@@ -353,6 +369,7 @@ class NordeaAnalyticsCoreService:
                 currency,
                 issuers,
                 asset_types,
+                instrument_groups,
                 lower_issue_date,
                 upper_issue_date,
                 lower_maturity,
@@ -382,8 +399,12 @@ class NordeaAnalyticsCoreService:
         ],
         calc_date: datetime,
         curves: Union[List[str], str, CurveName, List[CurveName]] = None,
-        shift_tenors: Union[List[float], float] = None,
-        shift_values: Union[List[float], float] = None,
+        shift_tenors: Union[
+            float, List[float], int, List[int], List[Union[float, int]]
+        ] = None,
+        shift_values: Union[
+            float, List[float], int, List[int], List[Union[float, int]]
+        ] = None,
         pp_speed: float = None,
         prices: Union[float, List[float]] = None,
         spread: float = None,
@@ -546,6 +567,26 @@ class NordeaAnalyticsCoreService:
         """
         return self._retrieve_value(FXForecast(self._client, currency_pair), as_df)
 
+    def get_quotes(
+        self,
+        symbols: Union[str, List[str]],
+        calc_date: datetime,
+        as_df: bool = False,
+    ) -> Any:
+        """Retrieves quotes.
+
+        Args:
+            symbols: The symbols for which to retrieve quotes.
+            calc_date: date of price.
+            as_df: Default False. If True, the results are represented
+                as pandas DataFrame, else as dictionary.
+
+        Returns:
+            Dictionary containing requested data. If as_df is True,
+                the data is in form of a DataFrame.
+        """
+        return self._retrieve_value(Quotes(self._client, symbols, calc_date), as_df)
+
     def get_yield_forecasts(
         self,
         country: Union[str, YieldCountry],
@@ -606,6 +647,33 @@ class NordeaAnalyticsCoreService:
             date_roll_convention,
         ).to_datetime()
 
+    def get_date_sequence(
+        self,
+        from_date: datetime,
+        to_date: datetime,
+        exchange: Union[str, Exchange] = None,
+        day_count_convention: Union[str, DayCountConvention] = None,
+    ) -> List:
+        """Shifts a date using internal holiday calendars.
+
+        Args:
+            from_date: The start date of the date sequence.
+            to_date: The end date of the date sequence.
+                Negative values move date back in time.
+            exchange: The exchange's holiday calendar will be used.
+            day_count_convention: The convention to use for counting days.
+
+        Returns:
+            List containing oredered datetimes is returned.
+        """
+        return DateSequence(
+            self._client,
+            from_date,
+            to_date,
+            exchange,
+            day_count_convention,
+        ).to_list_of_datetime()
+
     def get_shift_days(
         self,
         date: datetime,
